@@ -50,7 +50,7 @@ class TelegramLogger:
         Args:
             msg (str):
         """
-        self._msgs.append(self.format_msg(msg))
+        self._msgs.append(self._format_msg(msg))
 
         if self._callback is not None:
             self._callback(msg)
@@ -82,7 +82,7 @@ class TelegramLogger:
     def __call__(self, msg: str = "") -> None:
         self.send(msg)
 
-    def format_msg(self, msg: str = "") -> str:
+    def _format_msg(self, msg: str = "") -> str:
         """TODO
 
         Args:
